@@ -174,6 +174,31 @@ frames <- lapply(banana, function(frame) {
 animation <- image_animate(image_join(frames))
 print(animation)
 
+## ---- results="hide"-----------------------------------------------------
+# Produce image using graphics device
+fig <- image_device(res = 96)
+ggplot2::qplot(mpg, wt, data = mtcars, colour = cyl)
+dev.off()
+
+## ------------------------------------------------------------------------
+# Combine
+out <- image_composite(fig, frink, offset = "+70+30")
+print(out)
+
+## ---- results="hide"-----------------------------------------------------
+# Or paint over an existing image
+img <- image_draw(frink)
+rect(20, 20, 200, 100, border = "red", lty = "dashed", lwd = 5)
+abline(h = 300, col = 'blue', lwd = '10', lty = "dotted")
+text(10, 250, "Hoiven-Glaven", family = "courier", cex = 4, srt = 90)
+palette(rainbow(11, end = 0.9))
+symbols(rep(200, 11), seq(0, 400, 40), circles = runif(11, 5, 35),
+  bg = 1:11, inches = FALSE, add = TRUE)
+dev.off()
+
+## ------------------------------------------------------------------------
+print(img)
+
 ## ------------------------------------------------------------------------
 plot(as.raster(frink))
 
